SectionLocationData class

Constructors

SectionLocationData({required String kszam, required int km, required int m, required int pkod, required String szakLabel, required String leiras, required double wgs84X, required double wgs84Y})
SectionLocationData.fromJson(String source)
factory
SectionLocationData.fromMap(Map<String, dynamic> map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
km int
getter/setter pair
kszam String
getter/setter pair
leiras String
getter/setter pair
m int
getter/setter pair
pkod int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
szakLabel String
getter/setter pair
wgs84X double
getter/setter pair
wgs84Y double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited