SubtitleParams class

Constructors

SubtitleParams({required String imgPath, required bool resize, required SectionLocationData locData, required SendPort sendPort, required SendPort errorPort})

Properties

errorPort SendPort
final
hashCode int
The hash code for this object.
no setterinherited
imgPath String
final
locData SectionLocationData
final
resize bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendPort SendPort
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited